@@ -30,7 +30,11 @@
       paste0(sample(c(1:9, LETTERS, letters), 20, replace = T), collapse = ''),
     googleAuthR.tryAttempts = 5,
     googleAuthR.HttrRetryTimes = 3,
-    googleAuthR.HttrRetryTerminateOn = NULL
+    googleAuthR.HttrRetryTerminateOn = c(400,401,402,403,404,405,406,407,408,
+                                         409,410,411,412,413,414,415,416,417,
+                                         418,421,422,423,424,426,428,
+                                         431,451),
+    googleAuthR.redirect = "default"
   )
   toset <- !(names(op.googleAuthR) %in% names(op))
   if (any(toset)) options(op.googleAuthR[toset])
